@@ -8,7 +8,8 @@ from . import commands
 class Repl(Cmd):
     def __init__(self, target):
         super().__init__()
-        self.prompt = f'{target.name} > '
+        user = 'sudo' if target.sudo else target.distro.Login.name
+        self.prompt = f'{target.name}:{user} > '
         for name, cmd in commands.items():
             setattr(self, f'do_{name}', partial(cmd, target))
 
