@@ -21,7 +21,7 @@ class Packager(Manager):
     def installed(self, pattern=None):
         if pattern:
             for name, ver in self.do_installed():
-                if pattern == name:
+                if pattern in name:
                     yield name, ver
         else:
             yield from self.do_installed()
@@ -35,11 +35,11 @@ class Packager(Manager):
             yield from self.do_available()
 
     def update(self):
-        info('\ŧupdate')
+        info('\tupdate')
         self.do_update()
 
     def upgrade(self):
-        info('\ŧupgrade')
+        info('\tupgrade')
         self.do_upgrade()
 
     def install(self, name, ver=None):
