@@ -219,11 +219,6 @@ class Target:
         info(f'\tdeploy {module} {params} {status}')
         return ret
 
-    def __call__(self, command, **kw):
-        ret, out, err = self.run(command, **kw)
-        print('\n'.join(out))
-        return ret
-
     def rsync(self, *arg, **kw):
         self.Package.install('rsync')
         kw['sudo'] = False
