@@ -36,6 +36,9 @@ class Apt(Packager):
     def do_update(self):
         self.run('apt-get update')
 
+    def do_upgrade(self):
+        self.run('apt-get upgrade -y')
+
     def do_install(self, pkg, ver=None):
         ret, out, err = self.run('apt-get -y install %s%s' % (pkg, '=%s'%ver if ver else ''))
         err = [
