@@ -34,7 +34,10 @@ class Pacman(Packager):
         self.run('pacman --noconfirm -Scc')
 
     def do_update(self):
-        self.run('pacman -Syu')
+        self.run('pacman -Sy')
+
+    def do_upgrade(self):
+        self.run('pacman --noconfirm -Su')
 
     def do_install(self, pkg, ver=None):
         # self.run(f'pacman -S --needed --noconfirm {pkg}')
