@@ -16,6 +16,12 @@ class Local(Target):
         self.trace(' '.join(arg), ret, out, err, **kw)
         return ret, out, err
 
+    def __call__(self, command, **kw):
+        ret, out, err = self.run(command, **kw)
+        print('\n'.join(out))
+        print('\n'.join(err))
+        return ret
+
     def read(self, path, mode='rt', critical=True):
         info(f'\tread {path}')
         return open(path, mode).read()
